unit ExRegUtils;

{$mode objfpc}{$H+}

interface

uses SysUtils, Registry;

function ReadRegString(Key: String; ValueName: String; Default: String = ''): String;
function ReadRegFloat(Key: String; ValueName: String; Default: Double = 0): Double;
function ReadRegInteger(Key: String; ValueName: String; Default: Integer = 0): Integer;
function ReadRegBoolean(Key: String; ValueName: String; Default: Boolean = False): Boolean;

function WriteRegString(Key: String; ValueName: String; Value: String): Boolean;
function WriteRegFloat(Key: String; ValueName: String; Value: Double): Boolean;
function WriteRegInteger(Key: String; ValueName: String; Value: Integer): Boolean;
function WriteRegBoolean(Key: String; ValueName: String; Value: Boolean): Boolean;

function DelRegValue(Key: String; ValueName: String): Boolean;
function DelRegKey(Key: String): Boolean;

implementation

function ReadRegString(Key: String; ValueName: String; Default: String = ''): String;
var
  Regi: TRegistry;
begin
  try
    Regi := TRegistry.Create;
    Regi.RootKey := HKEY_CURRENT_USER;
    Regi.OpenKeyReadOnly(Key);
    if Regi.ValueExists(ValueName) then
      Result := Regi.ReadString(ValueName)
    else
      Result := Default;
  finally
    Regi.Free;
  end;
end;

function ReadRegFloat(Key: String; ValueName: String; Default: Double = 0): Double;
var
  Regi: TRegistry;
begin
  try
    Regi := TRegistry.Create;
    Regi.RootKey := HKEY_CURRENT_USER;
    Regi.OpenKeyReadOnly(Key);
    if Regi.ValueExists(ValueName) then
      Result := Regi.ReadFloat(ValueName)
    else
      Result := Default;
  finally
    Regi.Free;
  end;
end;

function ReadRegInteger(Key: String; ValueName: String; Default: Integer = 0): Integer;
var
  Regi: TRegistry;
begin
  try
    Regi := TRegistry.Create;
    Regi.RootKey := HKEY_CURRENT_USER;
    Regi.OpenKeyReadOnly(Key);
    if Regi.ValueExists(ValueName) then
      Result := Regi.ReadInteger(ValueName)
    else
      Result := Default;
  finally
    Regi.Free;
  end;
end;

function ReadRegBoolean(Key: String; ValueName: String; Default: Boolean = False): Boolean;
var
  Regi: TRegistry;
begin
  try
    Regi := TRegistry.Create;
    Regi.RootKey := HKEY_CURRENT_USER;
    Regi.OpenKeyReadOnly(Key);
    if Regi.ValueExists(ValueName) then
      Result := Regi.ReadBool(ValueName)
    else
      Result := Default;
  finally
    Regi.Free;
  end;
end;

function WriteRegString(Key: String; ValueName: String; Value: String): Boolean;
var
  Regi: TRegistry;
begin
  try
    Regi := TRegistry.Create;
    Regi.RootKey := HKEY_CURRENT_USER;
    Regi.OpenKey(Key, True);
    Regi.WriteString(ValueName, Value);
    Result := Regi.KeyExists(ValueName);
  finally
    Regi.Free;
  end;
end;

function WriteRegFloat(Key: String; ValueName: String; Value: Double): Boolean;
var
  Regi: TRegistry;
begin
  try
    Regi := TRegistry.Create;
    Regi.RootKey := HKEY_CURRENT_USER;
    Regi.OpenKey(Key, True);
    Regi.WriteFloat(ValueName, Value);
    Result := Regi.KeyExists(ValueName);
  finally
    Regi.Free;
  end;
end;

function WriteRegInteger(Key: String; ValueName: String; Value: Integer): Boolean;
var
  Regi: TRegistry;
begin
  try
    Regi := TRegistry.Create;
    Regi.RootKey := HKEY_CURRENT_USER;
    Regi.OpenKey(Key, True);
    Regi.WriteInteger(ValueName, Value);
    Result := Regi.KeyExists(ValueName);
  finally
    Regi.Free;
  end;
end;

function WriteRegBoolean(Key: String; ValueName: String; Value: Boolean): Boolean;
var
  Regi: TRegistry;
begin
  try
    Regi := TRegistry.Create;
    Regi.RootKey := HKEY_CURRENT_USER;
    Regi.OpenKey(Key, True);
    Regi.WriteBool(ValueName, Value);
    Result := Regi.KeyExists(ValueName);
  finally
    Regi.Free;
  end;
end;

function DelRegValue(Key: String; ValueName: String): Boolean;
var
  Regi: TRegistry;
begin
  try
    Regi := TRegistry.Create;
    Regi.RootKey := HKEY_CURRENT_USER;
    Regi.OpenKey(Key, True);
    Result := Regi.DeleteValue(ValueName);
  finally
    Regi.Free;
  end;
end;

function DelRegKey(Key: String): Boolean;
var
  Regi: TRegistry;
begin
  try
    Regi := TRegistry.Create;
    Regi.RootKey := HKEY_CURRENT_USER;
    Result := Regi.DeleteKey(Key);
  finally
    Regi.Free;
  end;
end;

end.
